import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardComponentModel} from "../../../../stores/DashboardComponentStore";
import {CheckboxField, useReadonlyContext} from "@rx-suite/ui";
import {t} from "@lingui/macro";

export type HorizontalCheckboxFieldProps = {
    component: DashboardComponentModel
}

export const DatalabelCheckboxField: React.FunctionComponent<HorizontalCheckboxFieldProps> = observer(({component}) => {
    const readOnly = useReadonlyContext();
    const label = t`Show Data Labels`;
    return <CheckboxField label={label}
                          name={`display_options.dataLabels.enabled`}
                          checked={!!component.viewModel.display_options?.dataLabels?.enabled}
                          disabled={readOnly}
                          onChange={component.handleChange}
                          hint={{
                              title: label,
                              text: t`If selected, labels will be added to chart segments to show their value`
                          }}
    />

});