import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardComponentModel} from "../../../stores/DashboardComponentStore";
import {LabLayoutStore} from "../../../stores/LabLayoutStore";
import {makeStyles} from "@material-ui/core/styles";
import {Grid} from "@material-ui/core";
import {LayoutDashboardViewRenderer} from "../../../stores/object/LayoutDashboardViewRenderer";
import {DashboardComponentTitle} from "../generic/DashboardComponentTitle";

export type DashboardComponentBarChartProps = {
    component: DashboardComponentModel
};

const useStyles = makeStyles({
    wrapperNoHeader: {
        height: '100%',
        width: '100%'
    },
    wrapperWithHeader: {
        height: '95%',
        width: '100%'
    },
    canvas: {
        touchAction: 'none',
        outline: 'none',
        height: '100%',
        width: '100%'
    }
});

export const DashboardComponentLabStatus: React.FunctionComponent<DashboardComponentBarChartProps> = observer(({component}) => {
    const classes = useStyles({header: false});

    const [canvasRenderer] = React.useState<LayoutDashboardViewRenderer>(new LayoutDashboardViewRenderer());

    const setCanvasRef = React.useCallback((e) => {
        canvasRenderer.setCanvasRef(e)
    }, [canvasRenderer]);
    const handleMouseMove = React.useCallback((e) => {
        canvasRenderer.handleMouseMove(e)
    }, [canvasRenderer]);

    React.useEffect(() => {
        const layout = LabLayoutStore.get(component.viewModel.parameters['lab_layout_id']);
        if (layout) {
            canvasRenderer.setLayout(layout);
        }
    }, [LabLayoutStore.models, canvasRenderer, component.viewModel.parameters['lab_layout_id']]);

    React.useEffect(() => {
        canvasRenderer.setData(component.viewModel.data, component.updated_at);
    }, [component.viewModel.data, canvasRenderer, component.updated_at]);

    return (
        <React.Fragment>
            <DashboardComponentTitle component={component}/>
            <Grid item
                  className={component.typographyTitleStyle.display === 'none' ? classes.wrapperNoHeader : classes.wrapperWithHeader}>
                <canvas
                    className={classes.canvas}
                    ref={setCanvasRef}
                    onMouseMove={handleMouseMove}
                />
            </Grid>
        </React.Fragment>
    );
});
