import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardComponentModel} from "../../../stores/DashboardComponentStore";
import {TreemapChart} from "@rx-suite/ui";
import {useGraphOptions} from "../../../hooks/useGraphOptions";

export type DashboardComponentTreemapProps = {
    component: DashboardComponentModel
};

export const DashboardComponentTreemap: React.FunctionComponent<DashboardComponentTreemapProps> = observer(({component}) => {
    const series = component.viewModel.data.series || [];
    const labels = (component.viewModel.data.categories || []).map((c: { name: string }) => c.name);
    const options = useGraphOptions(component);

    if (component.isNew) {
        const fakeSeries = [{
            data: [{
                x: 'A',
                y: 1
            }, {
                x: 'B',
                y: 1
            }, {
                x: 'C',
                y: 2
            }, {
                x: 'D',
                y: 3
            }]
        }];
        return <TreemapChart series={fakeSeries}
                             options={{
                                 ...options,
                                 colors: ['#DCDCDC', "#C0C0C0", "#808080", "#606060", "#404040"]
                             }}
        />;
    } else {
        const translatedSeries = series.map((s: { data: any[]; }) => {
            return {
                ...s,
                data: labels.map((label: string, i: number) => ({
                    x: label,
                    y: s.data[i] || 0,
                }))
            }
        });
        return <TreemapChart series={translatedSeries}
                             options={options}
        />
    }
});
