import * as React from "react";
import {DashboardModel} from "../../../../stores/DashboardStore";
import {FullscreenButton} from "@rx-suite/ui";
import {Typography} from "@material-ui/core";
import {Trans} from "@lingui/macro";
import {DashboardGrid} from "../../DashboardGrid";
import {makeStyles} from "@material-ui/core/styles";

export type DashboardLayoutTabProps = {
    dashboard: DashboardModel,
    readOnly: boolean
}

const useStyles = makeStyles(theme => ({
    fullscreenLayout: {
        height: `calc(100vh - 64px - ${theme.spacing(2)}px)`,
        "&:fullscreen": {
            height: '100vw',
            width: '100vh',
            overflow: 'auto',
            backgroundColor: '#fafafa',
            padding: theme.spacing(2),
        }
    },
    layoutTitle: {
        display: 'inline-block'
    },
    gridWrapper: {
        height: '100%'
    }
}));

export const DashboardLayoutTab: React.FunctionComponent<DashboardLayoutTabProps> = ({dashboard, readOnly}) => {
    const fullscreenLayoutRef = React.createRef<HTMLDivElement>();
    const classes = useStyles();

    return (
        <React.Fragment>
            <div>
                <Typography variant={'caption'}><Trans>Edit in Fullscreen</Trans></Typography>
                <FullscreenButton fullscreenRef={fullscreenLayoutRef}/>
            </div>
            <div className={classes.fullscreenLayout} ref={fullscreenLayoutRef}>
                <div className={classes.gridWrapper}>
                    <DashboardGrid dashboard={dashboard} editMode={!readOnly}/>
                </div>
            </div>
        </React.Fragment>
    )
};