import {createStyles, Divider, makeStyles, Theme} from "@material-ui/core";
import {t} from "@lingui/macro";
import * as React from "react";
import {observer} from "mobx-react-lite";
import {ModelSelect} from "@rx-suite/ui";
import {LabLayoutComponentModel} from "../../stores/LabLayoutComponentStore";

export type MachineComponentExtraSettingsProps = {
    model: LabLayoutComponentModel | undefined;
};

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        divider: {
            marginTop: theme.spacing(1),
            marginBottom: theme.spacing(1)
        }
    })
);

export const VisualAlertSettings: React.FunctionComponent<MachineComponentExtraSettingsProps> = observer(({model}) => {
    const classes = useStyles();

    const visualAlertOptions = React.useCallback(() => {
        return [
            {label: t`none`, value: 0},
            {label: t`2 minutes`, value: 120},
            {label: t`5 minutes`, value: 300},
            {label: t`10 minutes`, value: 600},
        ];
    }, []);

    if (!model || !model.isMachineComponent) {
        return null;
    }

    return (
        <React.Fragment>
            <Divider className={classes.divider}/>
            <ModelSelect name={"alert_after"} label={t`Visual Alert After`} options={visualAlertOptions()} hint={{
                title: t`Visual Alert`,
                text: t`If the machine is in an error state for longer than the specified period, its status indicator will begin to blink.`
            }}/>
        </React.Fragment>
    )
});