# == Schema Information
#
# Table name: dashboard_components
#
#  id                  :bigint           not null, primary key
#  data                :text
#  desc                :string
#  display_options     :string
#  display_type        :string
#  last_run_error      :string
#  name                :string
#  parameters          :text
#  queued              :boolean          default(FALSE), not null
#  refresh_interval    :integer
#  run_token           :string
#  created_at          :datetime         not null
#  updated_at          :datetime         not null
#  dashboard_target_id :bigint
#  run_user_id         :string
#
# Indexes
#
#  index_dashboard_components_on_dashboard_target_id  (dashboard_target_id)
#
# Foreign Keys
#
#  fk_rails_...  (dashboard_target_id => dashboard_targets.id) ON DELETE => cascade ON UPDATE => cascade
#
class DashboardComponent < ApplicationRecord
  belongs_to :dashboard_target
  has_many :dashboard_component_placements
  has_many :dashboards, through: :dashboard_component_placements

  def get_data!
    RxModule::Authorization.set_request_token(run_token || nil)
    touch
    resp = dashboard_target.get_data(parsed_parameters.merge!({"dashboard_component_id" => id}))
    # data can be the string queued or dashboard data
    if resp[:queued]
      Rails::logger.info { {msg: "Dashboard queued", component: as_json} }
      # if we dont set the previous data, then the scorecard disappears in the front-end
      update(last_run_error: nil, queued: true)
    elsif resp
      update(data: resp.to_json, last_run_error: nil, queued: false)
    else
      update(last_run_error: "No data returned", queued: false)
      Rails.logger.warn "Failed to receive data for #{as_json}"
    end
  rescue => err
    update(last_run_error: err.message)
    Rails.logger.warn "Failed to fetch data for #{as_json}"
  end

  def parsed_parameters
    if parameters && parameters != ""
      JSON.parse(parameters)
    else
      {}
    end
  end
end
