class UpdateDashboardDefinitions < RxModule::Routine
  class << self
    def frequency
      "1m"
    end

    def work
      ActiveRecord::Base.connection_pool.with_connection do
        RxModule::Communicator::Hub.list_modules.each do |mod|
          if mod[:type] == "RxModuleComponent" && mod[:module_id] != RxModule.module_id
            targets_to_keep = []
            Rails.logger.debug { {msg: "Checking Module Dashboard Definitions", module: mod} }
            RxModule::Communicator.call_module_method(mod[:module_id], "/api/rx_module/dashboards", :get).each do |dashboard_def|
              dirty = false
              report = DashboardTarget.where(module_id: mod[:module_id], dashboard_id: dashboard_def[:id]).first_or_create do
                dirty = true # block is only yielded if create is called
              end
              [:module_name].each do |k|
                if report[k] != mod[k]
                  dirty = true
                  report[k] = mod[k]
                end
              end
              [:name, :desc].each do |k|
                if report[k] != dashboard_def[k]
                  dirty = true
                  report[k] = dashboard_def[k]
                end
              end
              [:ui_hints, :parameters, :returns].each do |k|
                if report[k] != dashboard_def[k].to_json
                  dirty = true
                  report[k] = dashboard_def[k].to_json
                end
              end
              report.save if dirty
              targets_to_keep << report.id
            end
            DashboardTarget.where.not(id: targets_to_keep).where(module_id: mod[:module_id]).destroy_all
          end
        rescue
          Rails.logger.warn { {msg: "Module is not responding to dashboard definition request", module: mod} }
        end
      end
    end
  end
end
